@@ -24,7 +24,7 @@ class Mainmenu:
         self.win.set_title("Europe")
         self.win.remove(self.box)
         #self.options = Options()
-        game = Game("europe", "English", PRACTICE)
+        game = Game("europe", "English", NORMAL)
         game.show()
         self.win.add(game)
         #game.add_events(self.win, 256)
